%define upstream_name lexical-underscore
%define upstream_version 0.004

%{?perl_default_filter}

Name:		perl-%{upstream_name}
Version:	%perl_convert_version %{upstream_version}
Release:	%mkrel 3

Summary:	Access your caller's lexical underscore
License:	GPL+ or Artistic
Group:		Development/Perl
Url:		http://search.cpan.org/dist/%{upstream_name}
Source0:	http://www.cpan.org/modules/by-module/UNIVERSAL/TOBYINK/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires:	perl(PadWalker)

BuildArch:	noarch

Provides:	perl(lexical::underscore)

%description
Starting with Perl 5.10, it is possible to create a lexical version of
the Perl default variable $_. Certain Perl constructs like the "given"
keyword automatically use a lexical $_ rather than the global $_.

It is occasionallly useful for a sub to be able to access its caller's
$_ variable regardless of whether it was lexical or not. The "(_)" sub
prototype is the official way to do so, however there are sometimes
disadvantages to this; in particular it can only appear as the final
required argument in a prototype, and there is no way of the sub
differentiating between an explicitly passed argument and $_.

This caused me problems with Scalar::Does, because I wanted to enable
the "does" function to be called as either:

   does($thing, $role);
   does($role);  # assumes $thing = $_

With "_" in the prototype, $_ was passed to the function at the end of
its argument list; effectively "does($role, $thing)", making it
impossible to tell which argument was the role.

Enter "lexical::underscore" which allows you to access your caller's
lexical $_ variable as easily as:

   ${lexical::underscore()}

You can access lexical $_ further up the call stack using:

   ${lexical::underscore($level)}

If you happen to ask for $_ at a level where no lexical $_ is available,
you get the global $_ instead.

This module does work on Perl 5.8 but as there is no lexical $_, always
returns the global $_.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%__perl Makefile.PL INSTALLDIRS=vendor

%make

%check
%make test

%install
%make_install

%files
%doc Changes LICENSE META.yml MYMETA.yml README SIGNATURE
%{_mandir}/man3/*
%{perl_vendorlib}/*


%changelog
* Wed Feb 12 2020 umeabot <umeabot> 0.4.0-3.mga8
+ Revision: 1507138
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 0.4.0-2.mga7
+ Revision: 1287495
- Mageia 7 Mass Rebuild

* Mon Oct 09 2017 tv <tv> 0.4.0-1.mga7
+ Revision: 1170508
- new release

* Sun Jun 19 2016 pterjan <pterjan> 0.3.0-3.mga6
+ Revision: 1029134
- Rebuild for perl 5.22.2

* Fri Feb 19 2016 umeabot <umeabot> 0.3.0-2.mga6
+ Revision: 968438
- Mageia 6 Mass Rebuild

* Tue Jul 07 2015 sander85 <sander85> 0.3.0-1.mga6
+ Revision: 852477
- update to 0.003

* Wed Oct 15 2014 umeabot <umeabot> 0.1.0-4.mga5
+ Revision: 740222
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.1.0-3.mga5
+ Revision: 687035
- Mageia 5 Mass Rebuild

* Mon Oct 21 2013 umeabot <umeabot> 0.1.0-2.mga4
+ Revision: 537439
- Mageia 4 Mass Rebuild

* Thu Sep 26 2013 sander85 <sander85> 0.1.0-1.mga4
+ Revision: 487018
- imported package perl-lexical-underscore

